# IfcMerge

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ifc_ids** | **list[int]** |  | 
**floating_point_reduction** | **int** | Precision of geometries. 6 is micrometre, 9 is nanometre, ect... | [optional] 
**export_name** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


